@@ -5,7 +5,7 @@ fn test() {
 
     unsafe { set_mask(1) };
     assert_eq!(get_mask(), 1);
-    unsafe { disable_mask(1) };
+    disable_mask(1);
     assert_eq!(get_mask(), 0);
     unsafe { enable_mask(1) };
     assert_eq!(get_mask(), 1);
